Struct rustainers::compose::ComposeRunOption
source · pub struct ComposeRunOption { /* private fields */ }Expand description
Run options
Available options:
wait_interval: wait until re-check a container state (default 1s)wait_services_interval: wait until re-check that all services starting (default 96ms)env: a map of environment variables used when launch the containercompose-file: if you need to use another compose file (--fileoption)
Implementations
sourceimpl ComposeRunOption
impl ComposeRunOption
sourcepub fn builder() -> ComposeRunOptionBuilder<((), (), (), ())>
pub fn builder() -> ComposeRunOptionBuilder<((), (), (), ())>
Create a builder for building ComposeRunOption.
On the builder, call .wait_interval(...)(optional), .wait_services_interval(...)(optional), .env(...)(optional), .compose_file(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of ComposeRunOption.