WaitStrategy

Enum WaitStrategy 

#[non_exhaustive]
pub enum WaitStrategy { HealthCheck, CustomHealthCheck(HealthCheck), State(ContainerStatus), HttpSuccess { https: bool, require_valid_certs: bool, path: String, container_port: Port, }, ScanPort { container_port: Port, timeout: Duration, }, LogMatch { io: StdIoKind, matcher: LogMatcher, }, None, }
Wait strategies

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


HealthCheck

With the image health check



CustomHealthCheck(HealthCheck)

With custom health check



State(ContainerStatus)

Wait for the container state



HttpSuccess

Wait until the HTTP call provide a successful status (e.g. 200 OK)

Fields

https: bool

If we use HTTPS instead of HTTP

require_valid_certs: bool

If TLS certificates are validated.

Setting this field to false will allow self-signed certificates to be used. This setting is used only when https is set to true.

path: String

The path to check

container_port: Port

The container port



ScanPort

Wait until a socket is open

Fields

container_port: Port

The container port

timeout: Duration

The timeout for a try



LogMatch

Wait until log match a pattern

Fields

io: StdIoKind

the type of io

matcher: LogMatcher

The matcher



None

Do not wait

Implementations

Source

impl WaitStrategy

pub fn none() -> Self

No wait

pub fn health_check() -> Self

Wait with image healt check

pub fn custom_health_check(health_check: HealthCheck) -> Self

Wait with image healt check

pub fn state(state: ContainerStatus) -> Self

Wait for a state

pub fn http(path: impl Into<String>) -> Self

Wait for an successful HTTP call on the 80 port

pub fn https(path: impl Into<String>) -> Self

Wait for an successful HTTPS call on the 443 port

pub fn scan_port(container_port: impl Into<Port>) -> Self

Wait for a port to be open using a default timeout

pub fn stdout_contains(str: impl Into<String>) -> Self

Wait for a log line in stdout contains a string

pub fn stderr_contains(str: impl Into<String>) -> Self

Wait for a log line in stderr contains a string