Struct rustainers::ContainerId

source ·
pub struct ContainerId(/* private fields */);
A container id

The id is a SHA-252 represented as 32 bytes array. Therefore this type is Copy.

Note because some version of Docker CLI return truncated value, we need to store the size of the id.

Most usage of this type is done with the string representation.

Note that the Display view truncate the id, to have the full String you need to use the Into or From implementation.