Enum rustainers::WaitStrategy
source · #[non_exhaustive]pub enum WaitStrategy {
HealthCheck,
CustomHealthCheck(HealthCheck),
State(ContainerStatus),
HttpSuccess {
https: bool,
path: String,
container_port: Port,
},
ScanPort {
container_port: Port,
timeout: Duration,
},
LogMatch {
io: StdIoKind,
matcher: LogMatcher,
},
None,
}Expand description
Wait strategies
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
HealthCheck
With the image health check
CustomHealthCheck(HealthCheck)
With custom health check
State(ContainerStatus)
Wait for the container state
HttpSuccess
Wait until the HTTP call provide a successful status (e.g. 200 OK)
Fields
ScanPort
Wait until a socket is open
LogMatch
Wait until log match a pattern
None
Do not wait
Implementations
sourceimpl WaitStrategy
impl WaitStrategy
sourcepub fn health_check() -> Self
pub fn health_check() -> Self
Wait with image healt check
sourcepub fn custom_health_check(health_check: HealthCheck) -> Self
pub fn custom_health_check(health_check: HealthCheck) -> Self
Wait with image healt check
sourcepub fn state(state: ContainerStatus) -> Self
pub fn state(state: ContainerStatus) -> Self
Wait for a state
sourcepub fn https(path: impl Into<String>) -> Self
pub fn https(path: impl Into<String>) -> Self
Wait for an successful HTTPS call on the 443 port
sourcepub fn scan_port(container_port: impl Into<Port>) -> Self
pub fn scan_port(container_port: impl Into<Port>) -> Self
Wait for a port to be open using a default timeout
sourcepub fn stdout_contains(str: impl Into<String>) -> Self
pub fn stdout_contains(str: impl Into<String>) -> Self
Wait for a log line in stdout contains a string
sourcepub fn stderr_contains(str: impl Into<String>) -> Self
pub fn stderr_contains(str: impl Into<String>) -> Self
Wait for a log line in stderr contains a string