Struct rustainers::ExposedPort

source ·
pub struct ExposedPort { /* private fields */ }
Define an exposed port

An exposed port has two parts: the container port (inside), and the host port (outside). To talk to the container you need to use the host port.

Examples

You can omit the host port during construction, in that case, a default available port is chosen. For example, to create an exposed port targeting the container 80 port:

let port_mapping = ExposedPort::new(80);

You can set the host port, but be careful it can fail it’s already opened. For example, to create the exposed host port 8080 targeting the container 80 port:

let port_mapping = ExposedPort::fixed(80, 8080);

Implementations

source

impl ExposedPort

source

pub fn new(container_port: impl Into<Port>) -> ExposedPort

Create an exposed port

source

pub fn fixed( container_port: impl Into<Port>, host_port: impl Into<Port>, ) -> ExposedPort

Create an exposed port with a fixed host port

source

pub async fn host_port(&self) -> Result<Port, PortError>

Get the bound port (host)

Errors

Fail if the port is unbound

source

pub fn container_port(&self) -> Port

Get the container port